@@ -355,8 +355,9 @@ load_conduit_list (GPilotPilot *pilot)
 		conduit_state->config = gnome_pilot_conduit_config_new (conduit_state->management, pilot->pilot_id);
 		conduit_state->description = g_strdup ((gchar*) gnome_pilot_conduit_management_get_attribute (conduit_state->management, "description", NULL));
 		conduit_state->icon = g_strdup ((gchar*)gnome_pilot_conduit_management_get_attribute (conduit_state->management, "icon", NULL));
-		if (conduit_state->icon == NULL)
-			conduit_state->icon = gnome_unconditional_pixmap_file ("gnome-unknown.png");
+		if (conduit_state->icon == NULL || g_file_test (conduit_state->icon, G_FILE_TEST_ISFILE)==FALSE) {
+			conduit_state->icon = gnome_unconditional_pixmap_file ("gnome-palm-conduit.png");
+		}
 		
 		buf = (gchar*) gnome_pilot_conduit_management_get_attribute (conduit_state->management, "settings", NULL);
 		if (buf == NULL || buf[0] != 'T') 
