@@ -343,7 +343,8 @@ gnome_pilot_conduit_sync_abs_new (char *db_name,
 
 	retval =  gtk_object_new (gnome_pilot_conduit_sync_abs_get_type (),
 				  "GnomePilotConduitStandard::db_name", db_name,
-				  "GnomePilotConduitStandard::creator_id", creator_id);
+				  "GnomePilotConduitStandard::creator_id", creator_id,
+				  NULL);
 
 	return GTK_OBJECT (retval);
 }
