@@ -431,7 +431,7 @@ gpilot_network_device_init (GPilotDevice *device)
 
 /* This is used if the hostname is not correct in the conf file
    I'll move it to the conf file saving later */
-/*   fetch_host (device->host, 128, &address, &netmask);	*/
+	/* fetch_host (device->host, 128, &address, &netmask); */
 	
 /* device->host I already have from the config file */
 
@@ -445,8 +445,8 @@ gpilot_network_device_init (GPilotDevice *device)
 		}
 	}
 
-	if (!inet_aton (device->netmask, &netmask)) {
-		g_message ("Invalid ip address '%s'", device->ip);
+	if (inet_aton (device->netmask, &netmask) == 0) {
+		g_message ("Invalid netmask '%s'", device->netmask);
 		return -1;
 	}
 
@@ -472,9 +472,11 @@ gpilot_network_device_init (GPilotDevice *device)
 		g_message ("Unable to bind socket");
 		return -1;
 	}
-   
-	g_message (stderr, "Connection Service Daemon for Palm Computing (tm) device active.");
-	g_message (stderr, "Accepting connection requests for '%s' at %s with mask", device->host, inet_ntoa (address), inet_ntoa (netmask));
+	/*
+	g_message ("Connection Service Daemon for Palm Computing (tm) device active.");
+	g_message ("Accepting connection requests for '%s' at %s with mask %s", 
+		   device->host, inet_ntoa (address), inet_ntoa (netmask));
+	*/
 
 	/* We don't want to infinite loops here */
 	/* Lets try something else instead */
@@ -515,6 +517,10 @@ gpilot_device_init (GPilotDevice *device)
 	} else if (device->type == PILOT_DEVICE_USB_VISOR) {
 		result = gpilot_usb_device_init (device);
 #endif /* WITH_USB_VISOR */
+#ifdef WITH_NETWORK
+	} else if (device->type == PILOT_DEVICE_NETWORK) {
+		result = gpilot_network_device_init (device);
+#endif /* WITH_NETWORK */
 	} else {
 		g_warning (_("Unknown device type"));
 	}
@@ -806,7 +812,7 @@ gnome_pilot_conduit_sync_type_int_to_str(GnomePilotConduitSyncType e)
 	case GnomePilotConduitSyncTypeMergeToPilot:   return "merge_to_pilot";
 	case GnomePilotConduitSyncTypeNotSet:         return "not_set";
 	default: 
-	  g_message("gnome_pilot_conduit_sync_type_int_to_str: invalid sync_type %d",e);
+	  g_message ("gnome_pilot_conduit_sync_type_int_to_str: invalid sync_type %d",e);
 	  return "not_set";
 	}
 }
